@@ -82,8 +82,6 @@ class Writer(object):
 
     @description.setter
     def description(self, value):
-        if value is None:
-            self._description = ""
         if not isinstance(value, str):
             raise TypeError("description has to be of type str or None.")
         self._description = value
@@ -144,7 +142,7 @@ class Writer(object):
 
     @overwrite.setter
     def overwrite(self, value):
-        if not isinstance(value, np.int):
+        if not isinstance(value, int):
             raise TypeError("<overwrite> has to be of type bool.")
         if value:
             self._overwrite = True
@@ -158,7 +156,7 @@ class Writer(object):
 
     @dumping.setter
     def dumping(self, value):
-        if not isinstance(value, np.int):
+        if not isinstance(value, int):
             raise TypeError("<dumping> has to be of type bool.")
         if value:
             self._dumping = True
@@ -173,7 +171,7 @@ class Writer(object):
 
     @verbosity.setter
     def verbosity(self, value):
-        if not isinstance(value, np.int):
+        if not isinstance(value, int):
             raise TypeError("<verbosity> has to be of type int.")
         self._verbosity = value
 
@@ -184,8 +182,7 @@ class Writer(object):
 
     @zfill.setter
     def zfill(self, value):
-        value = np.int(value)
-        if not isinstance(value, np.int):
+        if not isinstance(value, int):
             raise TypeError("zfill has to be integer.")
         self._zfill = value
 
@@ -287,8 +284,8 @@ class Writer(object):
         while(True):
             filename = "temp_" + "".join(random.choice(string.ascii_uppercase)
                                          for i in range(5)) + ".dmp"
-            if not os.path.isfile(filename):
-                break
+            if not os.path.isfile(filename):    # pragma: no cover
+                break                           # Impossible to test due to randomness
         temp = IntVar(None, 0., snapshots=[0.])
         writedump(temp, filename)
         temp = Field(None, 0.)
@@ -305,13 +302,13 @@ class Writer(object):
         i : int
             Number of output
         forceoverwrite : boolean
-            If ``True`` it will forces and overwrite of the file if it exists.
+            If ``True`` it will forces and overwrite of the file if it exists independent of the writer attribute
         filename : string
             If this is not "" the writer will use this filename instead of the standard scheme"""
 
         if filename == "":
             filename = self._getfilename(i)
-            self.checkdatadir(createdir=True)
+        self.checkdatadir(createdir=True)
         if not forceoverwrite:
             if not self.overwrite:
                 if os.path.isfile(filename):
